summaryrefslogtreecommitdiffstats
path: root/kdict/sets.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:58:08 -0600
committerSlávek Banko <slavek.banko@axis.cz>2012-06-03 15:53:30 +0200
commite7bee19a9f42cffe3a0792348a60e5bee1d3da71 (patch)
tree92dabc7114bd352b2e4ebb5f64cd3d6429e162f7 /kdict/sets.cpp
parent4b54ad17739d1075235f2960ecde230a58b5621c (diff)
downloadtdenetwork-e7bee19a9f42cffe3a0792348a60e5bee1d3da71.tar.gz
tdenetwork-e7bee19a9f42cffe3a0792348a60e5bee1d3da71.zip
Remove additional unneeded tq method conversions
(cherry picked from commit 1de96857f5b0ed5d4a36e9486ffc8c7f8c802f98)
Diffstat (limited to 'kdict/sets.cpp')
-rw-r--r--kdict/sets.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/kdict/sets.cpp b/kdict/sets.cpp
index 3f043233..51dd7eb6 100644
--- a/kdict/sets.cpp
+++ b/kdict/sets.cpp
@@ -264,8 +264,8 @@ void DbSetsDialog::activateSet(int num)
w_set->clearEdit();
w_delete->setEnabled(false);
w_save->setEnabled(false);
- w_rightBox->tqrepaint(true); // Workaround for tqrepaint-bug
- w_leftBox->tqrepaint(true); // Workaround for tqrepaint-bug
+ w_rightBox->repaint(true); // Workaround for repaint-bug
+ w_leftBox->repaint(true); // Workaround for repaint-bug
} else {
w_set->setCurrentItem(num);
for (unsigned int i=0;i<global->serverDatabases.count();i++)
@@ -278,9 +278,9 @@ void DbSetsDialog::activateSet(int num)
w_delete->setEnabled(true);
w_save->setEnabled(true);
if (w_rightBox->count()==0)
- w_rightBox->tqrepaint(true); // Workaround for tqrepaint-bug
+ w_rightBox->repaint(true); // Workaround for repaint-bug
if (w_leftBox->count()==0)
- w_leftBox->tqrepaint(true); // Workaround for tqrepaint-bug
+ w_leftBox->repaint(true); // Workaround for repaint-bug
w_leftBox->clearSelection();
w_leftBox->centerCurrentItem();
w_rightBox->clearSelection();